import { Ref, JSONSchemaAttributeProducer } from "./JSONSchemaInput";
import { CompressedJSON } from "./CompressedJSON";
import { JSONSchemaStore } from "./JSONSchemaStore";
import { StringInput } from "../support/Support";
import { TypeBuilder } from "../TypeBuilder";
import { TargetLanguage } from "../TargetLanguage";
export interface Input<T> {
    readonly kind: string;
    readonly needIR: boolean;
    readonly needSchemaProcessing: boolean;
    addSource(source: T): Promise<void>;
    finishAddingInputs(): Promise<void>;
    singleStringSchemaSource(): string | undefined;
    addTypes(typeBuilder: TypeBuilder, inferMaps: boolean, inferEnums: boolean, fixedTopLevels: boolean): Promise<void>;
}
export interface JSONSourceData {
    name: string;
    samples: StringInput[];
    description?: string;
}
export declare class JSONInput implements Input<JSONSourceData> {
    private readonly _compressedJSON;
    readonly kind: string;
    readonly needIR: boolean;
    readonly needSchemaProcessing: boolean;
    private readonly _topLevels;
    constructor(_compressedJSON: CompressedJSON);
    private addSample(topLevelName, sample);
    private setDescription(topLevelName, description);
    addSource(source: JSONSourceData): Promise<void>;
    finishAddingInputs(): Promise<void>;
    singleStringSchemaSource(): undefined;
    addTypes(typeBuilder: TypeBuilder, inferMaps: boolean, inferEnums: boolean, fixedTopLevels: boolean): Promise<void>;
}
export declare function jsonInputForTargetLanguage(_targetLanguage: string | TargetLanguage, _languages?: TargetLanguage[]): JSONInput;
export interface JSONSchemaSourceData {
    name: string;
    uris?: string[];
    schema?: StringInput;
    isConverted?: boolean;
}
export declare class JSONSchemaInput implements Input<JSONSchemaSourceData> {
    readonly kind: string;
    readonly needSchemaProcessing: boolean;
    private _schemaStore;
    private readonly _attributeProducers;
    private readonly _schemaInputs;
    private _schemaSources;
    private readonly _topLevels;
    private _needIR;
    constructor(givenSchemaStore: JSONSchemaStore | undefined, additionalAttributeProducers?: JSONSchemaAttributeProducer[]);
    readonly needIR: boolean;
    addTopLevel(name: string, ref: Ref): void;
    addTypes(typeBuilder: TypeBuilder): Promise<void>;
    addSource(schemaSource: JSONSchemaSourceData): Promise<void>;
    finishAddingInputs(): Promise<void>;
    singleStringSchemaSource(): string | undefined;
}
export declare class InputData {
    private _inputs;
    addInput<T>(input: Input<T>): void;
    addSource<T>(kind: string, source: T, makeInput: () => Input<T>): Promise<void>;
    finishAddingInputs(): Promise<void>;
    addTypes(typeBuilder: TypeBuilder, inferMaps: boolean, inferEnums: boolean, fixedTopLevels: boolean): Promise<void>;
    readonly needIR: boolean;
    readonly needSchemaProcessing: boolean;
    singleStringSchemaSource(): string | undefined;
}
